#!/usr/bin/env python
# by Mel Chua
"""
You are a bird. Go "bombs away!" on cars.
Done after running through the excellent pygame tutorial here:
http://rene.f0o.com/mywiki/PythonGameProgramming
"""

#Import Modules
import os, pygame
from pygame.locals import *
from random import *

#functions to create our resources
def load_image(name, colorkey=None):
    fullname = os.path.join('images', name)
    try:
        image = pygame.image.load(fullname)
    except pygame.error, message:
        print 'Cannot load image:', fullname
        raise SystemExit, message
    image = image.convert()
    if colorkey is not None:
        if colorkey is -1:
            # This sets the color key (transparency)
            # with the color of the upper-left-hand pixel.
            colorkey = image.get_at((0,0))
        image.set_colorkey(colorkey, RLEACCEL)
    return image, image.get_rect()

#classes for our game objects
class Bird(pygame.sprite.Sprite):
    """Your character. It follows the mouse."""
    def __init__(self):
        pygame.sprite.Sprite.__init__(self) #call Sprite initializer
        self.image, self.rect = load_image('bird.png', -1)

    def update(self):
        "make the bird follow the mouse."
        pos = pygame.mouse.get_pos()
        self.rect.midtop = pos

    def poop(self, target):
        "returns true if poop hits car"
        hitbox = self.rect.inflate(100, 100)
        return hitbox.colliderect(target.rect)

class Poop(pygame.sprite.Sprite):
    """It's... poop."""
    def __init__(self):
        pygame.sprite.Sprite.__init__(self) #call Sprite initializer
        self.image, self.rect = load_image('poop.png', -1)
        self.pos = pygame.mouse.get_pos()

class Car(pygame.sprite.Sprite):
    """Moves a car across the screen. Spins it if the
       car gets pooped on."""

    def __init__(self):
        self.x = 0
        self.y = randint(0,640)
        pygame.sprite.Sprite.__init__(self) #call Sprite intializer
        self.image, self.rect = load_image('car.png', -1)
        screen = pygame.display.get_surface()
        self.area = screen.get_rect()
        self.rect.topleft = self.x, self.y
        self.move = 13
        # how many px to move forward each tick
        self.dizzy = 0

    def update(self):
        "drive or spin, depending on state"
        if self.dizzy:
            self._spin()
        else:
            self._drive()

    def _drive(self):
        """move the car across the screen,
         reposition y position when it drives offcreen"""
        newpos = self.rect.move((self.move, 0))
        if self.rect.left < self.area.left or \
            self.rect.right > self.area.right:
            self.rect.topleft = self.x, randint(0,640)
            newpos = self.rect.move((self.move, 0))
            self.image = pygame.transform.flip(self.image, 1, 0)
            print "newpos = ", newpos
        self.rect = newpos

    def _spin(self):
        "spin the car"
        center = self.rect.center
        self.dizzy = self.dizzy + 12
        if self.dizzy >= 360:
            self.dizzy = 0
            self.image = self.original
        else:
            rotate = pygame.transform.rotate
            self.image = rotate(self.original, self.dizzy)
        self.rect = self.image.get_rect(center=center)

    def pooped(self):
        "this will cause the car to start spinning"
        if not self.dizzy:
            self.dizzy = 1
            self.original = self.image
        

def main():

# initialize
    pygame.init()
    screen = pygame.display.set_mode((460,680))
    # hypothetically, the screen size should
    # be set with a variable that would be
    # easier to change (car y-coord random reset
    # depends on screen dimensions) but ehh
    pygame.display.set_caption('Birdsplat')
    pygame.mouse.set_visible(0)

#Create The Backgound
    background = pygame.Surface(screen.get_size())
    background = background.convert()
    background.fill((250, 250, 250))

# Display the Background
    screen.blit(background, (0,0))
    pygame.display.flip()

#Prepare Game Objects
    clock = pygame.time.Clock()
    bird = Bird()
    car = Car()
    allsprites = pygame.sprite.RenderPlain((bird, car))
    
#Main Loop
    while 1:
        clock.tick(60)

    #Handle Input Events
        for event in pygame.event.get():
            if event.type == QUIT:
                return
            elif event.type == KEYDOWN and event.key == K_ESCAPE:
                return
            elif event.type == MOUSEBUTTONDOWN:
                if bird.poop(car):
                    car.pooped()

        allsprites.update()

    #Draw Everything
        screen.blit(background, (0, 0))
        allsprites.draw(screen)
        pygame.display.flip()

#Game Over


#this calls the 'main' function when this script is executed
if __name__ == '__main__': main()
